@@ -2,8 +2,9 @@ use strict;
 use warnings;
 
 package MooseX::InsideOut;
-our $VERSION = '0.104';
-
+BEGIN {
+  $MooseX::InsideOut::VERSION = '0.105';
+}
 # ABSTRACT: inside-out objects with Moose
 
 use Moose ();
@@ -19,16 +20,17 @@ sub init_meta {
   shift;
   my %p = @_;
   Moose->init_meta(%p);
-  Moose::Util::MetaRole::apply_metaclass_roles(
-    for_class                => $p{for_class},
-    instance_metaclass_roles => [ 'MooseX::InsideOut::Role::Meta::Instance' ],
+  Moose::Util::MetaRole::apply_metaroles(
+    for             => $p{for_class},
+    class_metaroles => {
+        instance => [ 'MooseX::InsideOut::Role::Meta::Instance' ],
+    },
   );
 }
 
 1;
 
 
-
 =pod
 
 =head1 NAME
@@ -37,7 +39,7 @@ MooseX::InsideOut - inside-out objects with Moose
 
 =head1 VERSION
 
-version 0.104
+version 0.105
 
 =head1 SYNOPSIS
 
@@ -60,9 +62,15 @@ up attribute slot storage somewhere other than inside C<$self>.  This means
 that you can extend non-Moose classes, whose internals you either don't want to
 care about or aren't hash-based.
 
+=head1 METHODS
+
+=head2 init_meta
+
+Apply the instance metarole necessary for inside-out storage.
+
 =head1 TODO
 
-=over 
+=over
 
 =item * dumping (for debugging purposes)
 
@@ -70,29 +78,20 @@ care about or aren't hash-based.
 
 =item * (your suggestions here)
 
-=back 
-
-
-
-=head1 METHODS
-
-=head2 init_meta
-
-Apply the instance metarole necessary for inside-out storage.
+=back
 
 =head1 AUTHOR
 
-  Hans Dieter Pearcey <hdp@cpan.org>
+Hans Dieter Pearcey <hdp@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Hans Dieter Pearcey <hdp@cpan.org>.
+This software is copyright (c) 2010 by Hans Dieter Pearcey <hdp@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
 
 __END__
